window.Gleam.initSearch([{"doc":"testbldr","title":"testbldr","content":"# testbldr\n\n[![Package Version](https://img.shields.io/hexpm/v/testbldr)](https://hex.pm/packages/testbldr)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/testbldr/)\n\nThis library is a dead simple set of utilities for building test suites programatically.\nMost of the time it makes sense to have one test signature per test, and have those tests\nautomatically discovered and run.\nOther times you may want to read test cases in from files, json responses, etc. \nThis library is for the second case.\n\n# Example\n\n```gleam\nimport testbldr\nimport gleam/list\nimport gleam/int\n\npub fn main() {\n  let test_runner =\n    testbldr.test_runner_default()\n    |&gt; testbldr.include_passing_tests_in_output(True)\n    |&gt; testbldr.output_results_to_stdout()\n\n  let tests = {\n    use n &lt;- list.map([1, 3, 5, 8, 9])\n    use &lt;- testbldr.named(int.to_string(n) &lt;&gt; &quot; is odd&quot;)\n    case n % 2 == 1 {\n      True -&gt; testbldr.Pass\n      False -&gt; testbldr.Fail(int.to_string(n) &lt;&gt; &quot; is even, not odd&quot;)\n    }\n  }\n\n  test_runner\n  |&gt; testbldr.run(tests)\n}\n```\n","url":"index.html"},{"doc":"testbldr","title":"Test","content":"pub type Test {\n  Test(name: String, test_function: fn() -&gt; TestOutcome)\n}\n A test has a name and a body (a function which returns a TestOutcome)\nTest(name: String, test_function: fn() -&gt; TestOutcome)\n\n\nSynonyms:\ntestbldr.Test\ntestbldr Test","url":"testbldr.html#Test"},{"doc":"testbldr","title":"TestOutcome","content":"pub type TestOutcome {\n  Pass\n  Fail(msg: String)\n}\n A test can either pass or fail with a given reason\nPass\n\n\nFail(msg: String)\n\n\nSynonyms:\ntestbldr.TestOutcome\ntestbldr TestOutcome","url":"testbldr.html#TestOutcome"},{"doc":"testbldr","title":"TestRunner","content":"pub opaque type TestRunner\n Configuration for how to run a set of tests\n\nSynonyms:\ntestbldr.TestRunner\ntestbldr TestRunner","url":"testbldr.html#TestRunner"},{"doc":"testbldr","title":"display_ratio_using","content":"pub fn display_ratio_using(\n  runner: TestRunner,\n  printer printer: fn(Int, Int) -&gt; String,\n) -&gt; TestRunner\n How to print the ratio of passing to failing tests\nSynonyms:\ntestbldr.display_ratio_using\ntestbldr display_ratio_using","url":"testbldr.html#display_ratio_using"},{"doc":"testbldr","title":"display_test_outcome_using","content":"pub fn display_test_outcome_using(\n  runner: TestRunner,\n  printer printer: fn(String, TestOutcome) -&gt; String,\n) -&gt; TestRunner\n How to print an individual test outcome\nSynonyms:\ntestbldr.display_test_outcome_using\ntestbldr display_test_outcome_using","url":"testbldr.html#display_test_outcome_using"},{"doc":"testbldr","title":"include_passing_tests_in_output","content":"pub fn include_passing_tests_in_output(\n  runner: TestRunner,\n  input: Bool,\n) -&gt; TestRunner\n Set whether to include passing tests in the output\nSynonyms:\ntestbldr.include_passing_tests_in_output\ntestbldr include_passing_tests_in_output","url":"testbldr.html#include_passing_tests_in_output"},{"doc":"testbldr","title":"named","content":"pub fn named(name: String, new_test: fn() -&gt; TestOutcome) -&gt; Test\n Creates a new test with the given name\nSynonyms:\ntestbldr.named\ntestbldr named","url":"testbldr.html#named"},{"doc":"testbldr","title":"output_results_to_file","content":"pub fn output_results_to_file(\n  runner: TestRunner,\n  path path: String,\n) -&gt; TestRunner\n Write the test run output to a file\nSynonyms:\ntestbldr.output_results_to_file\ntestbldr output_results_to_file","url":"testbldr.html#output_results_to_file"},{"doc":"testbldr","title":"output_results_to_stdout","content":"pub fn output_results_to_stdout(runner: TestRunner) -&gt; TestRunner\n Write the test run output to stdout\nSynonyms:\ntestbldr.output_results_to_stdout\ntestbldr output_results_to_stdout","url":"testbldr.html#output_results_to_stdout"},{"doc":"testbldr","title":"run","content":"pub fn run(runner: TestRunner, tests: List(Test)) -&gt; Nil\n Runs a list of tests with the provided test runner\nSynonyms:\ntestbldr.run\ntestbldr run","url":"testbldr.html#run"},{"doc":"testbldr","title":"test_runner_default","content":"pub fn test_runner_default() -&gt; TestRunner\n Create a new test runner with the default configuration\nSynonyms:\ntestbldr.test_runner_default\ntestbldr test_runner_default","url":"testbldr.html#test_runner_default"},{"doc":"testbldr","title":"testbldr","content":"","url":"testbldr.html"},{"doc":"testbldr/should","title":"be_error","content":"pub fn be_error(a: Result(a, b)) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_error\ntestbldr/should be_error","url":"testbldr/should.html#be_error"},{"doc":"testbldr/should","title":"be_false","content":"pub fn be_false(a: Bool) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_false\ntestbldr/should be_false","url":"testbldr/should.html#be_false"},{"doc":"testbldr/should","title":"be_ok","content":"pub fn be_ok(a: Result(a, b)) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_ok\ntestbldr/should be_ok","url":"testbldr/should.html#be_ok"},{"doc":"testbldr/should","title":"be_true","content":"pub fn be_true(a: Bool) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_true\ntestbldr/should be_true","url":"testbldr/should.html#be_true"},{"doc":"testbldr/should","title":"equal","content":"pub fn equal(a: a, b: a) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.equal\ntestbldr/should equal","url":"testbldr/should.html#equal"},{"doc":"testbldr/should","title":"not_equal","content":"pub fn not_equal(a: a, b: a) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.not_equal\ntestbldr/should not_equal","url":"testbldr/should.html#not_equal"},{"doc":"testbldr/should","title":"testbldr/should","content":" A collection of assertion functions for use in tests, similar to gleeunit&#39;s `should` module.","url":"testbldr/should.html"}]);